//
// Copyright © 2017 Arm Ltd. All rights reserved.
// SPDX-License-Identifier: MIT
//

extern unsigned char g_TfLiteSchemaText[];
extern unsigned int g_TfLiteSchemaText_len;
